package org.daiquiri.examples;


import static org.daiquiri.Daiquiri.Naming.*;

import org.mockito.Mockito;
import org.testng.Assert;
import org.testng.annotations.Test;

import javax.naming.InitialContext;

public class LicenseCheckerTest {

    LicenseChecker checker = new LicenseChecker(10);

    @Test
    public void can_add_users_return_true() throws Exception{
        InitialContext mockContext = mockInitialContext();
        mockContext.bind(LicenseChecker.MAX_LICENSE, new Integer(15));

        Assert.assertTrue(checker.canAddUsers(4));
    }

    @Test
    public void can_add_users_return_false() throws Exception{
        InitialContext mockContext = mockInitialContext();
        mockContext.bind(LicenseChecker.MAX_LICENSE, new Integer(15));

        Assert.assertFalse(checker.canAddUsers(6));
    }

    @Test
    public void can_add_users_return_true_with_mockito() throws Exception{
        InitialContext mockContext = Mockito.mock(InitialContext.class);
        Mockito.when(mockContext.lookup(LicenseChecker.MAX_LICENSE)).thenReturn(new Integer(15));
        mockInitialContext(mockContext);

        Assert.assertTrue(checker.canAddUsers(4));
    }

    @Test
    public void can_add_users_return_false_with_mockito() throws Exception{
        InitialContext mockContext = Mockito.mock(InitialContext.class);
        Mockito.when(mockContext.lookup(LicenseChecker.MAX_LICENSE)).thenReturn(new Integer(15));
        mockInitialContext(mockContext);

        Assert.assertFalse(checker.canAddUsers(6));
    }
}
